==> qtjambi-qt3dcore-6.5.1-sources.jar: io/qt/qt3d/core/QNodeIdTypePair.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class Qt3DCore::QNodeIdTypePair</p>
 */
public class QNodeIdTypePair extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QNodeIdTypePair(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNodeIdTypePair instance);
    
    public QNodeIdTypePair(io.qt.qt3d.core.@NonNull QNodeId _id, io.qt.core.@Nullable QMetaObject _type){
        super((QPrivateConstructor)null);
        initialize_native(this, _id, _type);
    }
    
    private native static void initialize_native(QNodeIdTypePair instance, io.qt.qt3d.core.QNodeId _id, io.qt.core.QMetaObject _type);
    
    @QtUninvokable
    public final void setId(io.qt.qt3d.core.@NonNull QNodeId id){
        setId_native_cref_Qt3DCore_QNodeId(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
    }
    
    @QtUninvokable
    private native void setId_native_cref_Qt3DCore_QNodeId(long __this__nativeId, long id);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #id()} instead.</p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId getId() {
        return id();
    }
    
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId id(){
        return id_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QNodeId id_native(long __this__nativeId);
    
    @QtUninvokable
    public final void setType(io.qt.core.@Nullable QMetaObject type){
        setType_native_const_QMetaObject_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), type);
    }
    
    @QtUninvokable
    private native void setType_native_const_QMetaObject_ptr(long __this__nativeId, io.qt.core.QMetaObject type);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #type()} instead.</p>
     */
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject getType() {
        return type();
    }
    
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject type(){
        return type_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QMetaObject type_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QNodeIdTypePair(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QNodeIdTypePair clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QNodeIdTypePair clone_native(long __this_nativeId);
}

==> qtjambi-qt3dcore-6.5.2-sources.jar: io/qt/qt3d/core/QNodeIdTypePair.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>Qt3DCore::QNodeIdTypePair</code></p>
 */
public class QNodeIdTypePair extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>Qt3DCore::QNodeIdTypePair::<wbr>QNodeIdTypePair()</code></p>
     */
    public QNodeIdTypePair(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNodeIdTypePair instance);
    
    /**
     * <p>See <code>Qt3DCore::QNodeIdTypePair::<wbr>QNodeIdTypePair(Qt3DCore::QNodeId,<wbr>const QMetaObject*)</code></p>
     */
    public QNodeIdTypePair(io.qt.qt3d.core.@NonNull QNodeId _id, io.qt.core.@Nullable QMetaObject _type){
        super((QPrivateConstructor)null);
        initialize_native(this, _id, _type);
    }
    
    private native static void initialize_native(QNodeIdTypePair instance, io.qt.qt3d.core.QNodeId _id, io.qt.core.QMetaObject _type);
    
    /**
     * <p>See <code>Qt3DCore::QNodeIdTypePair::<wbr>id</code></p>
     */
    @QtUninvokable
    public final void setId(io.qt.qt3d.core.@NonNull QNodeId id){
        setId_native_cref_Qt3DCore_QNodeId(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
    }
    
    @QtUninvokable
    private native void setId_native_cref_Qt3DCore_QNodeId(long __this__nativeId, long id);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #id()} instead.</p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId getId() {
        return id();
    }
    
    /**
     * <p>See <code>Qt3DCore::QNodeIdTypePair::<wbr>id</code></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId id(){
        return id_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QNodeId id_native(long __this__nativeId);
    
    /**
     * <p>See <code>Qt3DCore::QNodeIdTypePair::<wbr>type</code></p>
     */
    @QtUninvokable
    public final void setType(io.qt.core.@Nullable QMetaObject type){
        setType_native_const_QMetaObject_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), type);
    }
    
    @QtUninvokable
    private native void setType_native_const_QMetaObject_ptr(long __this__nativeId, io.qt.core.QMetaObject type);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #type()} instead.</p>
     */
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject getType() {
        return type();
    }
    
    /**
     * <p>See <code>Qt3DCore::QNodeIdTypePair::<wbr>type</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject type(){
        return type_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QMetaObject type_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNodeIdTypePair(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QNodeIdTypePair clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QNodeIdTypePair clone_native(long __this_nativeId);
}
